@@ -1,22 +1,73 @@
 package Archive::BagIt::Fast;
 use strict;
 use warnings;
-use IO::AIO ();
-use Carp qw( croak );
+use Carp qw( carp croak );
 use Time::HiRes qw( time );
 use Moo;
+use IO::AIO ();
+use Net::SSLeay ();
 extends "Archive::BagIt";
 
-our $VERSION = '0.081'; # VERSION
 
-# ABSTRACT: A module to use IO::AIO to het better performance
+our $VERSION = '0.083'; # VERSION
 
+# ABSTRACT: A module to use L<IO::AIO> to get better performance
+
+
+sub BEGIN {
+    Net::SSLeay::OpenSSL_add_all_digests();
+}
+
+sub _XXX_digest {
+    my $digestobj = shift;
+    my $data_ref = shift;
+    my $data = ${ $data_ref };
+    Net::SSLeay::EVP_DigestUpdate($digestobj->_digest, $data);
+    my $result = Net::SSLeay::EVP_DigestFinal($digestobj->_digest);
+    Net::SSLeay::EVP_MD_CTX_destroy($digestobj->_digest);
+    delete $digestobj->{_digest};
+    my $digest = unpack('H*', $result);
+    return $digest;
+
+}
+
+sub sysread_based_digest {
+    my $digestobj = shift;
+    my $fh = shift;
+    my $filesize = shift;
+    my $data;
+    sysread $fh, $data, $filesize;
+    return _XXX_digest( $digestobj, \$data);
+}
+
+sub mmap_based_digest {
+    my $digestobj = shift;
+    my $fh = shift;
+    my $filesize = shift;
+    my $data='';
+    if ($filesize > 0) {
+        if (! IO::AIO::mmap $data, $filesize, IO::AIO::PROT_READ, IO::AIO::MAP_SHARED, $fh) {
+            carp "mmap fails, fall back to sysread";
+            sysread $fh, $data, $filesize;
+        };
+    }
+    return _XXX_digest($digestobj, \$data);
+}
 
 has 'digest_callback' => (
     is      => 'ro',
     lazy    => 1,
+
     builder => sub {
         my ($self) = shift;
+        #my $sub = sub {
+        #    my ($digestobj, $filename) = @_;
+        #    open(my $fh, "<:raw", "$filename") or croak ("Cannot open $filename, $!");
+        #    binmode($fh);
+        #    my $digest = $digestobj->get_hash_string($fh);
+        #    close $fh || croak("could not close file '$filename', $!");
+        #    return $digest;
+        #};
         my $sub = sub {
             my $digestobj = shift;
             my $filename =shift;
@@ -28,22 +79,11 @@ has 'digest_callback' => (
             $self->{stats}->{size} += $filesize;
             my $start_time = time();
             my $digest;
-            my $data;
             if ($filesize < $MMAP_MIN ) {
-                sysread $fh, $data, $filesize;
-                Net::SSLeay::EVP_DigestUpdate($digestobj->_digest, $data);
-                my $result = Net::SSLeay::EVP_DigestFinal($digestobj->_digest);
-                Net::SSLeay::EVP_MD_CTX_destroy($digestobj->_digest);
-                delete $digestobj->{_digest};
-                $digest = unpack('H*', $result);
+                return sysread_based_digest($digestobj, $fh, $filesize);
             }
             elsif ( $filesize < 1500000000) {
-                IO::AIO::mmap $data, $filesize, IO::AIO::PROT_READ, IO::AIO::MAP_SHARED, $fh or croak "mmap: $!";
-                Net::SSLeay::EVP_DigestUpdate($digestobj->_digest, $data);
-                my $result = Net::SSLeay::EVP_DigestFinal($digestobj->_digest);
-                Net::SSLeay::EVP_MD_CTX_destroy($digestobj->_digest);
-                delete $digestobj->{_digest};
-                $digest = unpack('H*', $result);
+                return mmap_based_digest($digestobj, $fh, $filesize);
             }
             else {
                 $digest = $digestobj->get_hash_string($fh);
@@ -68,11 +108,11 @@ __END__
 
 =head1 NAME
 
-Archive::BagIt::Fast - A module to use IO::AIO to het better performance
+Archive::BagIt::Fast - A module to use L<IO::AIO> to get better performance
 
 =head1 VERSION
 
-version 0.081
+version 0.083
 
 =head1 NAME
 
@@ -90,7 +130,15 @@ typical file size, filesystem and storage systems.
 =item digest_callback()
 
 register a callback function with method to calculate and return all digests for a a list of files using a Digest-object. This method implements fast
-file access using memory mapped I/O by IO::AIO.
+file access using memory mapped I/O by L<IO::AIO>.
+
+=item mmap_based_digest($digestobj, $fh, $filesize)
+
+internal funtion which uses mmap to calculate digest. Called by C<digest_callback>
+
+=item sysread_based_digest($digestobj, $fh, $filesize)
+
+internal function which uses sysread to calculate digest. Called by C<digest_callback>
 
 =back
 
