@@ -4,7 +4,7 @@ use warnings;
 use Moo;
 with 'Archive::BagIt::Role::Manifest';
 # ABSTRACT: The role to load md5 plugin (default for v0.97)
-our $VERSION = '0.081'; # VERSION
+our $VERSION = '0.083'; # VERSION
 
 has '+plugin_name' => (
     is => 'ro',
@@ -30,16 +30,6 @@ sub BUILD {
     return 1;
 }
 
-sub verify_file {
-    my ($self, $fh) = @_;
-    return;
-}
-
-sub verify {
-    my ($self) =@_;
-    return;
-}
-
 1;
 
 __END__
@@ -54,7 +44,7 @@ Archive::BagIt::Plugin::Manifest::MD5 - The role to load md5 plugin (default for
 
 =head1 VERSION
 
-version 0.081
+version 0.083
 
 =head1 AVAILABILITY
 
