@@ -2,9 +2,10 @@ package Archive::BagIt::Role::Plugin;
 use strict;
 use warnings;
 use Moo::Role;
+use IO::Async::Loop;
 use namespace::autoclean;
 # ABSTRACT: A role that handles plugin loading
-our $VERSION = '0.081'; # VERSION
+our $VERSION = '0.083'; # VERSION
 
 has plugin_name => (
   is  => 'ro',
@@ -12,6 +13,13 @@ has plugin_name => (
   default => __PACKAGE__,
 );
 
+has '_ioloop' => (
+    is      => 'ro',
+    default => sub {
+        IO::Async::Loop->new();
+    }
+);
+
 has bagit => (
   is  => 'ro',
   #isa => 'Archive::BagIt',
@@ -40,7 +48,7 @@ Archive::BagIt::Role::Plugin - A role that handles plugin loading
 
 =head1 VERSION
 
-version 0.081
+version 0.083
 
 =head1 AVAILABILITY
 
